#version 330 core
out vec4 FragColor;

in vec3 fsNormal;
in vec3 fsFragPos;

uniform vec3 eyePos;
uniform vec3 pointLightPosition;
uniform vec3 pointLightColor;

/*
vec3 calculatePointLighting(vec3 pointLightPosition, vec3 objPosition, vec3 normal, vec3 viewDir)
{
	float intensity = 0.6f;
	float pointLightRadius = 5.0f;
	float distFromObjectToLight = length(pointLightPosition - objPosition);

	vec3 lightDir = normalize(pointLightPosition - objPosition);
	float di = clamp(dot(normal, lightDir), 0, 1);

    vec3 diffuse = di * pointLightColor;

    float falloff = clamp(1 - (distFromObjectToLight/pointLightRadius), 0.0, 1.0);
    vec3 finalColor = diffuse * pow(falloff, intensity);

    return finalColor;
}
*/

vec3 calculatePointLighting(vec3 pointLightPosition, vec3 objPosition, vec3 normal, vec3 viewDir)
{
	float distFromObjectToLight = length(pointLightPosition - objPosition);

	vec3 lightDir = normalize(pointLightPosition - objPosition);
	float di = clamp(dot(normal, lightDir), 0, 1);

	vec3 half = normalize( lightDir + viewDir );
	float si = clamp(dot(normal, half), 0, 1);

    vec3 diffuse = di * pointLightColor;
    vec3 specular = pow(si, 8.0) * vec3(1);

    // Point Light Formula
	//http://ogldev.atspace.co.uk/www/tutorial20/tutorial20.html
    float exp = 0.01;
    float falloff = distFromObjectToLight + (exp * distFromObjectToLight * distFromObjectToLight);
    vec3 finalColor = (diffuse + specular) / falloff;

    return finalColor;
}

void main()
{
	vec3 viewDir = normalize(eyePos - fsFragPos);
	vec3 lightDir = vec3(0,1,1);
	vec3 normal = normalize(fsNormal);

	vec3 finalColor = calculatePointLighting(pointLightPosition, fsFragPos, normal, viewDir);

    FragColor = vec4(finalColor, 1.0f);
} 